
Miyadaiku
=========================================================================

Miyadaiku is a flexible static site generator for Jinja2 artists.

- Contents are written in reStructuredText, Markdown, HTML, Jupyter Notebook and YAML.

- Jinja2 templates to create HTML pages.

- Jinja2 tags can be used in your contents too. Miyadaiku provides ReST/Markdown extensions to write Jinja2 in content files. 

- Hierarchical contents property. Each directory can have default property values for documents. These property values are also applied to contents of their sub-directories.

- Theme system to share templates, CSS, Javascript, Image or any other contents files.

- Themes are managed as Python package. You can install themes from PyPI with pip.

- Generate index pages and Atom/RSS feeds for Blog sites.


Documents
--------------------

https://miyadaiku.github.io

Requirements
------------------

Miydaiku requires Python 3.6 or later.


Installation
-----------------

Use pip to install miyadaiku.

.. code:: console

   $ pip3 install miyadaiku

